@@ -1,3 +1,6 @@
+# Copyright (c) Jupyter Development Team.
+# Distributed under the terms of the Modified BSD License.
+
 # Configuration file for the Sphinx documentation builder.
 #
 # This file only contains a selection of the most common options. For a full
@@ -20,23 +23,18 @@ import sys
 HERE = osp.abspath(osp.dirname(__file__))
 sys.path.insert(0, osp.join(HERE, "..", ".."))
 
+from jupyterlab_server import LabServerApp, _version  # noqa
+
 # -- Project information -----------------------------------------------------
 
 project = "JupyterLab Server"
 copyright = "2021, Project Jupyter"  # noqa
 author = "Project Jupyter"
 
-# The full version, including alpha/beta/rc tags
-_version_py = osp.join(HERE, "..", "..", "jupyterlab_server", "_version.py")
-version_ns = {}
-
-with open(_version_py) as version_file:
-    exec(version_file.read(), version_ns)  # noqa
-
 # The short X.Y version.
-version = "%i.%i" % version_ns["version_info"][:2]
+version = "%i.%i" % _version.version_info[:2]
 # The full version, including alpha/beta/rc tags.
-release = version_ns["__version__"]
+release = _version.__version__
 
 # -- General configuration ---------------------------------------------------
 
@@ -54,6 +52,14 @@ extensions = [
     "sphinx_copybutton",
 ]
 
+try:
+    import enchant  # type:ignore  # noqa
+
+    extensions += ["sphinxcontrib.spelling"]
+except ImportError:
+    pass
+
+
 myst_enable_extensions = ["html_image"]
 
 # Add any paths that contain templates here, relative to this directory.
@@ -76,6 +82,7 @@ html_theme = "pydata_sphinx_theme"
 # Add an Edit this Page button
 html_theme_options = {
     "use_edit_page_button": True,
+    "navigation_with_keys": False,
 }
 
 # Output for github to be used in links
@@ -90,9 +97,44 @@ html_context = {
 # so disable
 numpydoc_show_class_members = False
 
+config_header = """\
+.. _api-full-config:
+
+
+Config file and command line options
+====================================
+
+The JupyterLab Server can be run with a variety of command line arguments.
+A list of available options can be found below in the :ref:`options section
+<options>`.
+
+Defaults for these options can also be set by creating a file named
+``jupyter_jupyterlab_server_config.py`` in your Jupyter folder. The Jupyter
+folder is in your home directory, ``~/.jupyter``.
+
+To create a ``jupyter_jupyterlab_server_config.py`` file, with all the defaults
+commented out, you can use the following command line::
+
+  $ python -m jupyterlab_server --generate-config
+
+
+.. _options:
+
+Options
+-------
+
+This list of options can be generated by running the following and hitting
+enter::
+
+  $ python -m jupyterlab_server --help-all
+
+"""
+
 
 def setup(app):
     dest = osp.join(HERE, "changelog.md")
     shutil.copy(osp.join(HERE, "..", "..", "CHANGELOG.md"), dest)
-    with open(osp.join(HERE, "../autogen_config.py")) as f:
-        exec(compile(f.read(), "../autogen_config.py", "exec"), {})  # noqa
+    destination = osp.join(HERE, "api/app-config.rst")
+    with open(destination, "w") as f:
+        f.write(config_header)
+        f.write(LabServerApp().document_config_options())
