@@ -2,30 +2,30 @@
 
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
+from __future__ import annotations
 
 import json
+from logging import Logger
 
 import requests
 import tornado
-
-from .server import APIHandler
+from jupyter_server.base.handlers import APIHandler
 
 LISTINGS_URL_SUFFIX = "@jupyterlab/extensionmanager-extension/listings.json"
 
 
-def fetch_listings(logger):
+def fetch_listings(logger: Logger | None) -> None:
     """Fetch the listings for the extension manager."""
     if not logger:
         from traitlets import log
 
-        logger = log.get_logger()
+        logger = log.get_logger()  # type:ignore[assignment]
+    assert logger is not None
     if len(ListingsHandler.blocked_extensions_uris) > 0:
         blocked_extensions = []
         for blocked_extensions_uri in ListingsHandler.blocked_extensions_uris:
             logger.info(
-                "Fetching blocked_extensions from {}".format(
-                    ListingsHandler.blocked_extensions_uris
-                )
+                f"Fetching blocked_extensions from {ListingsHandler.blocked_extensions_uris}"
             )
             r = requests.request(
                 "GET", blocked_extensions_uri, **ListingsHandler.listings_request_opts
@@ -38,9 +38,7 @@ def fetch_listings(logger):
         allowed_extensions = []
         for allowed_extensions_uri in ListingsHandler.allowed_extensions_uris:
             logger.info(
-                "Fetching allowed_extensions from {}".format(
-                    ListingsHandler.allowed_extensions_uris
-                )
+                f"Fetching allowed_extensions from {ListingsHandler.allowed_extensions_uris}"
             )
             r = requests.request(
                 "GET", allowed_extensions_uri, **ListingsHandler.listings_request_opts
@@ -49,7 +47,7 @@ def fetch_listings(logger):
             for w in j["allowed_extensions"]:
                 allowed_extensions.append(w)
         ListingsHandler.allowed_extensions = allowed_extensions
-    ListingsHandler.listings = json.dumps(  # type:ignore
+    ListingsHandler.listings = json.dumps(  # type:ignore[attr-defined]
         {
             "blocked_extensions_uris": list(ListingsHandler.blocked_extensions_uris),
             "allowed_extensions_uris": list(ListingsHandler.allowed_extensions_uris),
@@ -79,13 +77,15 @@ class ListingsHandler(APIHandler):
     allowed_extensions: list = []
     # The provider request options to be used for the request library.
     listings_request_opts: dict = {}
+    # The callback time for the periodic callback in seconds.
+    listings_refresh_seconds: int
     # The PeriodicCallback that schedule the call to fetch_listings method.
     pc = None
 
-    def get(self, path):
+    def get(self, path: str) -> None:
         """Get the listings for the extension manager."""
         self.set_header("Content-Type", "application/json")
         if path == LISTINGS_URL_SUFFIX:
-            self.write(ListingsHandler.listings)  # type:ignore
+            self.write(ListingsHandler.listings)  # type:ignore[attr-defined]
         else:
             raise tornado.web.HTTPError(400)
