@@ -1,3 +1,6 @@
+# Copyright (c) Jupyter Development Team.
+# Distributed under the terms of the Modified BSD License.
+
 import os
 import sys
 import warnings
@@ -9,7 +12,7 @@ from jupyterlab_server.process_app import ProcessApp
 
 
 def test_which():
-    assert which("python")
+    assert which("jupyter")
 
 
 async def test_process():
@@ -43,4 +46,4 @@ def test_process_app():
     # Kandle exception on older versions of server.
     except Exception as e:
         # Convert to warning so the test will pass on min version test.
-        warnings.warn(str(e))
+        warnings.warn(str(e))  # noqa B028
